/*
 * StatusCodeTest.java
 *
 * Copyright (c) 2015-2021, Erik C. Thauvin (erik@thauvin.net)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 *   Neither the name of this project nor the names of its contributors may be
 *   used to endorse or promote products derived from this software without
 *   specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package net.thauvin.erik.httpstatus;

import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
import org.testng.annotations.Test;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertFalse;
import static org.testng.Assert.assertTrue;

/**
 * StatusCode Tests.
 *
 * @author <a href="mailto:erik@thauvin.net" target="_blank">Erik C. Thauvin</a>
 */
@SuppressFBWarnings("CE_CLASS_ENVY")
public class StatusCodeTest {
    @Test
    void testStatusCode() {
        StatusCode statusCode = new StatusCode();
        statusCode.setCode(100);
        assertEquals(statusCode.getCode(), 100, "100 is 100");
        assertTrue(statusCode.isInfo(), "100 is informational");

        statusCode = new StatusCode(200);
        assertEquals(statusCode.getCode(), 200, "200 is 200");
        assertTrue(statusCode.isSuccess(), "200 is OK");

        statusCode.setCode(300);
        assertTrue(statusCode.isRedirect(), "300 is redirect");

        statusCode.setCode(400);
        assertTrue(statusCode.isClientError(), "400 is client error");
        assertTrue(statusCode.isError(), "400 is error");

        statusCode.setCode(500);
        assertTrue(statusCode.isServerError(), "500 is server error");
        assertTrue(statusCode.isError(), "500 is error");
        assertEquals(statusCode.getReason(), Reasons.getReasonPhrase(500), "500 reason phrase");
        assertTrue(statusCode.isValid(), "500 is valid");

        statusCode.setCode(600);
        assertFalse(statusCode.isValid(), "600 is invalid()");
    }
}
